@@ -7,7 +7,7 @@
 #              Text::BibTeX:Name class.)
 # CREATED    : Nov 1997, Greg Ward
 # MODIFIED   : 
-# VERSION    : $Id$
+# VERSION    : $Id: NameFormat.pm 8423 2010-02-13 20:40:27Z ambs $
 # COPYRIGHT  : Copyright (c) 1997-2000 by Gregory P. Ward.  All rights
 #              reserved.
 # 
@@ -22,8 +22,6 @@ require 5.004;
 
 use strict;
 use Carp;
-use vars qw'$VERSION';
-$VERSION = 0.76_02;
 
 =head1 NAME
 
@@ -31,9 +29,7 @@ Text::BibTeX::NameFormat - format BibTeX-style author names
 
 =head1 SYNOPSIS
 
-   use Text::BibTeX::NameFormat;
-
-   $format = Text::BibTeX::NameFormat->($parts, $abbrev_first);
+   $format = new Text::BibTeX::NameFormat ($parts, $abbrev_first);
 
    $format->set_text ($part,
                       $pre_part, $post_part,
@@ -41,7 +37,6 @@ Text::BibTeX::NameFormat - format BibTeX-style author names
 
    $format->set_options ($part, $abbrev, $join_tokens, $join_part
 
-   ## Uses the encoding/binmode and normalization form stored in $name
    $formatted_name = $format->apply ($name);
 
 =head1 DESCRIPTION
@@ -97,22 +92,22 @@ is joined to the next part (C<"la Roche"> versus C<"la~Roche">).
 
 =over 4
 
-=item new(PARTS, ABBREV_FIRST)
+=item new (PARTS, ABBREV_FIRST)
 
-Creates a new name format, with the two most common customizations: which
-parts to include (and in what order), and whether to abbreviate the first
-name.  PARTS should be a string with at most four characters, one representing
-each part that you want to occur in a formatted name (defaults to C<"fvlj">).
-For example, C<"fvlj"> means to format names in "first von last jr" order,
-while C<"vljf"> denotes "von last jr first."  ABBREV_FIRST is just a boolean
-value: false to print out the first name in full, and true to abbreviate it
-with periods after each token and discretionary ties between tokens (defaults
-to false).  All intra- and inter-token punctuation and spacing is independently
-controllable with the C<set_text> and C<set_options> methods, although these
-will rarely be necessary---sensible defaults are chosen for everything, based
-on the PARTS and ABBREV_FIRST values that you supply.  See the description of
-C<bt_create_name_format()> in L<bt_format_names> for full details of the
-choices made.
+Creates a new name format, with the two most common customizations:
+which parts to include (and in what order), and whether to abbreviate
+the first name.  PARTS should be a string with at most four characters,
+one representing each part that you want to occur in a formatted name.
+For example, C<"fvlj"> means to format names in "first von last jr"
+order, while C<"vljf"> denotes "von last jr first."  ABBREV_FIRST is
+just a boolean value: false to print out the first name in full, and
+true to abbreviate it with periods after each token and discretionary
+ties between tokens.  All intra- and inter-token punctuation and spacing
+is independently controllable with the C<set_text> and C<set_options>
+methods, although these will rarely be necessary---sensible defaults are
+chosen for everything, based on the PARTS and ABBREV_FIRST values that
+you supply.  See the description of C<bt_create_name_format()> in
+L<bt_format_names> for full details of the choices made.
 
 =cut
 
@@ -120,11 +115,6 @@ sub new
 {
    my ($class, $parts, $abbrev_first) = @_;
 
-   $parts ||= "fvlj";
-   $abbrev_first = defined($abbrev_first)? $abbrev_first : 0;
-
-   die unless $parts =~ /[fvlj]{1,4}/;
-
    $class = ref ($class) || $class;
    my $self = bless {}, $class;
    $self->{_cstruct} = create ($parts, $abbrev_first);
@@ -245,12 +235,7 @@ sub apply
       croak "invalid Name object: no C structure";
    my $format_struct = $self->{'_cstruct'} ||
       croak "invalid NameFormat object: no C structure";
- 
-   my $ans = format_name ($name_struct, $format_struct);
-
-   $ans = Text::BibTeX->_process_result($ans, $name->{binmode}, $name->{normalization});
-   
-   return $ans;
+   format_name ($name_struct, $format_struct);
 }
 
 =back
@@ -268,7 +253,7 @@ The first step is covered in L<Text::BibTeX::Name>; here's a brief
 example:
 
    $orig_name = 'Charles Louis Xavier Joseph de la Vall{\'e}e Poussin';
-   $name = Text::BibTeX::Name->new($orig_name);
+   $name = new Text::BibTeX::Name $orig_name;
 
 The various parts of the name can now be accessed through
 C<Text::BibTeX::Name> methods; for instance C<$name-E<gt>part('von')>
@@ -276,7 +261,7 @@ returns the list C<("de","la")>.
 
 Creating the name format is equally simple:
 
-   $format = Text::BibTeX::NameFormat->new('vljf', 1);
+   $format = new Text::BibTeX::NameFormat ('vljf', 1);
 
 creates a format that will print the name in "von last jr first" order,
 with the first name abbreviated.  And for no extra charge, you get the
@@ -319,7 +304,3 @@ is part of the Text::BibTeX library.  This library is free software; you
 may redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
-
-
-1;
-
